#ifndef OS_CONFIG_H
#define OS_CONFIG_H 1

#undef ORBIT_HAVE_ALLOCA_H
#define MAXIOV 1024

#endif
